# MBASIC Data Management

Database and file management programs

## Available Data Management

### Mfil



**Year:** 1980s
**Tags:** 

**[Download mfil.bas](mfil.bas)**

---

### Sfamove



**Year:** 1980s
**Tags:** 

**[Download sfamove.bas](sfamove.bas)**

---

### Sfaobdes



**Year:** 1980s
**Tags:** 

**[Download sfaobdes.bas](sfaobdes.bas)**

---

### Sfavoc



**Year:** 1980s
**Tags:** 

**[Download sfavoc.bas](sfavoc.bas)**

---

### Xlabels



**Year:** 1980s
**Tags:** 

**[Download xlabels.bas](xlabels.bas)**

---

## How to Use

1. **Download** the .bas file you want to use
2. **Open MBASIC** in your preferred UI (Web, Tkinter, Curses, or CLI)
3. **Load the file:**
   - **Web/Tkinter UI:** Click File → Open, select the downloaded file
   - **CLI:** Type `LOAD "filename.bas"`
4. **Run:** Type `RUN` or press the Run button

## About These Data Management

These programs are from the CP/M and early PC era (1970s-1980s), 
preserved from historical archives including OAK, Simtel, and CP/M CD-ROMs.
